@@ -14,16 +14,21 @@ class EvaluateEnv(eagerx.BaseEnv):
         if render == "pybullet":
             name = f"{env.name}_pybullet_eval"
             robot = graph.get_spec("quadruped")
-            graph.set(5, robot.sensors.image, parameter="rate")
+            robot.sensors.image.rate = 5
             graph.add_component(robot.sensors.image)
-            graph.render(robot.sensors.image, rate=5)
+            graph.render(robot.sensors.image, rate=5, encoding="rgb")
             graph.remove("xy_plane")
         else:
             name = f"{env.name}_xyplane_eval"
             xy_plane = graph.get_spec("xy_plane")
-            graph.render(xy_plane.outputs.image, rate=5)
+            xy_plane.outputs.image.rate = 5
 
-        super(EvaluateEnv, self).__init__(name, self.rate, graph, engine, force_start=True)
+        # Make the backend specification
+        from eagerx.backends.single_process import SingleProcess
+
+        backend = SingleProcess.make()
+
+        super(EvaluateEnv, self).__init__(name, self.rate, graph, engine, backend, force_start=True)
         self.timeout_steps = int(episode_timeout * self.rate)
         self.steps = None
 
@@ -44,13 +49,15 @@ class EvaluateEnv(eagerx.BaseEnv):
 
         # set camera location
         if "quadruped/image/pos" in states:
-            states["quadruped/image/pos"] = np.array([-1, -1, 0.5])
+            states["quadruped/image/pos"] = np.array([-1, -1, 0.5], dtype="float32")
         if "quadruped/image/orientation" in states:
             tmp = list(pybullet.getQuaternionFromEuler(np.deg2rad([-90, 0, 0])))
-            states["quadruped/image/orientation"] = np.array(tmp)
+            states["quadruped/image/orientation"] = np.array(tmp, dtype="float32")
 
         # Perform reset
         obs = self._reset(states)
+        if "xs_zs" in obs:
+            obs["xs_zs"][0][:] = [-0.01354526, -0.26941818, 0.0552178, -0.25434446]
         return obs
 
     def step(self, action: Dict) -> Tuple[Dict, float, bool, Dict]:
